function [full_sol,full_sol_x] = analytic_dual(x,L,t,K,C,theta,NN);

%  function [full_sol,full_sol_x] = analytic_dual(x,L,t,K,C,theta,NN);

% Computes fourier solution to 
% C u_t = K u_xx + S_t
% with C and K constant
% and S_t 
% S(x,t) is given to be 
% S(x,t) = theta1(t)(x-L) + theta2(t)
% and theta1 = theta(:,1:2);
% and theta2 = theta(:,1:2:3);

tic
nu = K/C;

TL = length(t);
TX = length(x);
T1t = myinterp1(theta(:,1:2),t);
T2t = myinterp1(theta(:,1:2:3),t);

dT1 = diff(T1t)./diff(t);
dT2 = diff(T2t)./diff(t);

for n = 1:NN
  mu(n) = (n-1/2)*pi/L;
  S(n) = 2*(T1t(1)*cos(mu(n)*L) + T2t(1)*sin(mu(n)*L)*mu(n) - T1t(1)) ...
                   / (L*mu(n)^2)	;
  Sp(n,1:TL-1) = 2*(dT1*cos(mu(n)*L) + dT2*sin(mu(n)*L)*mu(n) - dT1) ...
                   / (L*mu(n)^2);	
end

w0 = -1*S(:);

solh =  zeros(TX,TL);
solhx =  zeros(TX,TL);
solp = zeros(TX,TL);
solpx = zeros(TX,TL);

xm = repmat(x(:),1,TL);
tm = repmat(t(:)',TX,1);

Sm = repmat(T1t(:)',TX,1) .* (xm - L) + repmat(T2t(:)',TX,1);  
Smx = repmat(T1t(:)',TX,1);

for n = 1:NN
   solh = solh + cos(mu(n)*xm)*w0(n).* exp(-nu*mu(n)^2.*tm);
   solhx = solhx - mu(n)*xm.*sin(mu(n)*xm)*w0(n).* exp(-nu*mu(n)^2.*tm);
   integral = 0;
   for k = 2:TL
     interval = [t(k-1),t(k)];
     outside(k) = exp(-nu*mu(n)^2*t(k));
     subintegral(k) = trapz([interval],exp(-nu*mu(n)^2*interval)*Sp(n,k-1));
   end
   % assemble convolution 
   innerint = cumsum(subintegral);
   fn = innerint .* outside;
   fnm = repmat(fn,TX,1);
   solp = solp + fnm .* cos(mu(n)*xm);
   solpx = solpx - mu(n)*xm.*sin(mu(n)*xm).*fnm;
end

full_sol = solh + solp + Sm ; 
full_sol_x = solhx + solpx + Smx;

toc
